@@ -6,3 +6,5 @@ from opengsq.protocols.quake1 import Quake1
 from opengsq.protocols.quake2 import Quake2
 from opengsq.protocols.quake3 import Quake3
 from opengsq.protocols.source import Source
+from opengsq.protocols.unreal2 import Unreal2
+from opengsq.protocols.won import WON
