@@ -14,10 +14,6 @@ class GameSpy2(ProtocolBase):
         PLAYERS = auto()
         TEAMS = auto()
 
-    def __init__(self, address: str, query_port: int, timeout: float = 5.0):
-        """GameSpy Query Protocol version 2"""
-        super().__init__(address, query_port, timeout)
-
     async def get_status(self, request: Request = Request.INFO | Request.PLAYERS | Request.TEAMS) -> dict:
         """Retrieves information about the server including, Info, Players, and Teams."""
         # Connect to remote host
