@@ -1,6 +1,7 @@
 import re
 
 from opengsq.binary_reader import BinaryReader
+from opengsq.exceptions import InvalidPacketException
 from opengsq.protocol_base import ProtocolBase
 from opengsq.socket_async import SocketAsync
 
@@ -10,10 +11,6 @@ class GameSpy3(ProtocolBase):
     full_name = 'GameSpy Query Protocol version 3'
     challenge = False
 
-    def __init__(self, address: str, query_port: int, timeout: float = 5.0):
-        """GameSpy Query Protocol version 3"""
-        super().__init__(address, query_port, timeout)
-
     async def get_status(self):
         """Retrieves information about the server including, Info, Players, and Teams."""
         # Connect to remote host
@@ -137,10 +134,6 @@ class GameSpy3(ProtocolBase):
         return response
 
 
-class InvalidPacketException(Exception):
-    pass
-
-
 if __name__ == '__main__':
     import asyncio
     import json
